@@ -77,7 +77,6 @@ enum
 	USE_FONTS_PROP,
 	MIN_SIZE_PROP,
 	USE_COLORS_PROP,
-	SMOOTHSCROLL_PROP,
 	CSS_CONTAINER_PROP,
 	CSS_CHECKBOX_PROP,
 	CSS_EDIT_BOX_PROP,
@@ -121,7 +120,6 @@ EphyDialogProperty properties [] =
 	{ "use_fonts_checkbutton",	CONF_RENDERING_USE_OWN_FONTS,	PT_AUTOAPPLY | PT_INVERTED,	0 },
 	{ "min_size_spinbutton",	CONF_RENDERING_FONT_MIN_SIZE,	PT_AUTOAPPLY,	0 },
 	{ "use_colors_checkbutton",	CONF_RENDERING_USE_OWN_COLORS,	PT_AUTOAPPLY | PT_INVERTED,	0 },
-	{ "smoothscroll_button",	CONF_DISPLAY_SMOOTHSCROLL,	PT_AUTOAPPLY,	0 },
 	{ "css_container",		NULL,				PT_NORMAL,	0 },
 	{ "css_checkbox",		CONF_USER_CSS_ENABLED,		PT_AUTOAPPLY,	0 },
 	{ "css_edit_box",		NULL,				PT_NORMAL,	0 },
@@ -906,13 +904,16 @@ download_path_changed_cb (GtkFileChooser *button)
 	desktop_dir = ephy_file_desktop_dir ();
 	g_return_if_fail (downloads_dir != NULL && desktop_dir != NULL);
 
+	/* Check if the dir matches the default downloads_dir or desktop_dir to
+	 * store the english name instead of the localized one reported by the
+	 * two ephy_file_ functions. */
 	if (strcmp (dir, downloads_dir) == 0)
 	{
-		eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, "Downloads");
+		eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, _("Downloads"));
 	}
 	else if (strcmp (dir, desktop_dir) == 0)
 	{
-		eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, "Desktop");
+		eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, _("Desktop"));
 	}
 	else
 	{
